# -*- coding: utf-8 -*-
#
# Copyright (C) 2014-17 alvations
# URL:
# For license information, see LICENSE.md

from distutils.core import setup

setup(
    name='lazyme',
    version='0.0.22',
    packages=['lazyme',],
    url = 'https://github.com/alvations/lazyme',
    description='Lazy python recipes',
    license="MIT",
)
